"""Load and validate JSON data from files, access to entries.
"""
from __future__ import absolute_import

import unittest
import os
import sys

import json,jsonschema
jval = None

from jsondata.JSONDataSerializer import JSONDataSerializer as ConfigData

# name of application, used for several filenames as default
_APPNAME = "jsondatacheck"
appname = _APPNAME

#
#######################
#
class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    def testCase000(self):
        """Load a data file.
        """
        global jval
        global datafile

        # data
        datafile = os.path.abspath(os.path.dirname(__file__))+os.sep+str('datafile.json')
        if not os.path.isfile(datafile):
            raise BaseException("Missing JSON data:file="+str(datafile))
        # load data
        with open(datafile) as data_file:
            jval = json.load(data_file)
        if jval == None:
            raise BaseException("Failed to load data:"+str(data_file))

        jval = jval
        assert jval
        pass

    def testCase010(self):
        """Load a schema file.
        """
        global sval
        global datafile
        global schemafile

        # schema
        schemafile = os.path.abspath(os.path.dirname(__file__))+os.sep+str('schema.jsd')
        if not os.path.isfile(schemafile):
            raise BaseException("Missing JSONschema:file="+str(schemafile))
        with open(schemafile) as schema_file:
            sval = json.load(schema_file)
        if sval == None:
            raise BaseException("Failed to load schema:"+str(schema_file))


    def testCase020(self):
        """Create an object for data only - no schema - ConfigData.OFF.
        """
        global jval
        global sval
        global configdata
        global appname
        global schemafile

        kargs = {}
        kargs['configfile'] = datafile
        kargs['schemafile'] = schemafile
        kargs['nodefaultpath'] = True
        kargs['nosubdata'] = True
        kargs['pathlist'] = os.path.dirname(__file__)
        kargs['validator'] = ConfigData.OFF
        configdata = ConfigData(appname,**kargs)

    def testCase030(self):
        """Replace object with a new including validator - ConfigData.DEFAULT.
        """
        global jval
        global sval
        global configdata
        global appname
        global schemafile

        kargs = {}
        kargs['configfile'] = datafile
        kargs['schemafile'] = schemafile
        kargs['nodefaultpath'] = True
        kargs['nosubdata'] = True
        kargs['pathlist'] = os.path.dirname(__file__)
        kargs['validator'] = ConfigData.DEFAULT
        configdata = ConfigData(appname,**kargs)

    def testCase040(self):
        """Replace object with a new including validator - ConfigData.DRAFT3.
        """
        global jval
        global sval
        global configdata
        global appname
        global schemafile

        kargs = {}
        kargs['configfile'] = datafile
        kargs['schemafile'] = schemafile
        kargs['nodefaultpath'] = True
        kargs['nosubdata'] = True
        kargs['pathlist'] = os.path.dirname(__file__)
        kargs['validator'] = ConfigData.DRAFT3
        configdata = ConfigData(appname,**kargs)


    def testCase900(self):
        """Access data by static references.
        """
        global configdata

        assert configdata.data["address"]["streetAddress"] == "21 2nd Street"
        assert configdata.data["address"]["city"] == "New York"
        assert configdata.data["address"]["houseNumber"] == 12

    def testCase901(self):
        """Access another data by static references.
        """
        global configdata

        assert configdata.data["phoneNumber"][0]["type"] == "home"
        assert configdata.data["phoneNumber"][0]["number"] == "212 555-1234"
        pass

    def testCase920(self):
        """Access data by dynamic references.
        """
        global configdata

        assert configdata.data["address"]["streetAddress"] == jval["address"]["streetAddress"]
        assert configdata.data["address"]["city"] == jval["address"]["city"]
        assert configdata.data["address"]["houseNumber"] == jval["address"]["houseNumber"]

    def testCase921(self):
        """Access another data by dynamic references.
        """
        global configdata

        assert configdata.data["phoneNumber"][0]["type"] == jval["phoneNumber"][0]["type"]
        assert configdata.data["phoneNumber"][0]["number"] == jval["phoneNumber"][0]["number"]
        pass

#
#######################
#
if __name__ == '__main__':
    unittest.main()
